Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(531)

Unified Diff: third_party/WebKit/Source/platform/heap/BlinkGC.h

Issue 1754183002: Rename BaseHeap to BaseArena (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Node.h ('k') | third_party/WebKit/Source/platform/heap/BlinkGCDesign.md » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/platform/heap/BlinkGC.h
diff --git a/third_party/WebKit/Source/platform/heap/BlinkGC.h b/third_party/WebKit/Source/platform/heap/BlinkGC.h
index 688525a1d3873572ad96be47c19950114f3d7897..a54525a3a0f174312ea199459091ca92ea5fb089 100644
--- a/third_party/WebKit/Source/platform/heap/BlinkGC.h
+++ b/third_party/WebKit/Source/platform/heap/BlinkGC.h
@@ -25,16 +25,16 @@ using WeakCallback = VisitorCallback;
using EphemeronCallback = VisitorCallback;
using PreFinalizerCallback = bool(*)(void*);
// List of typed heaps. The list is used to generate the implementation
// of typed heap related methods.
//
// To create a new typed heap add a H(<ClassName>) to the
// FOR_EACH_TYPED_HEAP macro below.
#define FOR_EACH_TYPED_HEAP(H) \
H(Node) \
H(CSSValue)
-#define TypedHeapEnumName(Type) Type##HeapIndex,
+#define TypedArenaEnumName(Type) Type##ArenaIndex,
class PLATFORM_EXPORT BlinkGC final {
STATIC_ONLY(BlinkGC);
@@ -80,21 +80,21 @@ public:
};
enum HeapIndices {
- EagerSweepHeapIndex = 0,
- NormalPage1HeapIndex,
- NormalPage2HeapIndex,
- NormalPage3HeapIndex,
- NormalPage4HeapIndex,
- Vector1HeapIndex,
- Vector2HeapIndex,
- Vector3HeapIndex,
- Vector4HeapIndex,
- InlineVectorHeapIndex,
- HashTableHeapIndex,
- FOR_EACH_TYPED_HEAP(TypedHeapEnumName)
- LargeObjectHeapIndex,
+ EagerSweepArenaIndex = 0,
+ NormalPage1ArenaIndex,
+ NormalPage2ArenaIndex,
+ NormalPage3ArenaIndex,
+ NormalPage4ArenaIndex,
+ Vector1ArenaIndex,
+ Vector2ArenaIndex,
+ Vector3ArenaIndex,
+ Vector4ArenaIndex,
+ InlineVectorArenaIndex,
+ HashTableArenaIndex,
+ FOR_EACH_TYPED_ARENA(TypedArenaEnumName)
+ LargeObjectArenaIndex,
// Values used for iteration of heap segments.
- NumberOfHeaps,
+ NumberOfArenas,
};
#if defined(ADDRESS_SANITIZER)
« no previous file with comments | « third_party/WebKit/Source/core/dom/Node.h ('k') | third_party/WebKit/Source/platform/heap/BlinkGCDesign.md » ('j') | no next file with comments »
@@ -25,16 +25,16 @@ using WeakCallback = VisitorCallback;
using EphemeronCallback = VisitorCallback;
using PreFinalizerCallback = bool(*)(void*);
-// List of typed heaps. The list is used to generate the implementation
-// of typed heap related methods.
+// List of typed arenas. The list is used to generate the implementation
+// of typed arena related methods.
//
@@ -25,16 +25,16 @@ using WeakCallback = VisitorCallback;
//
-// To create a new typed heap add a H(<ClassName>) to the
-// FOR_EACH_TYPED_HEAP macro below.
-#define FOR_EACH_TYPED_HEAP(H) \
+// To create a new typed arena add a H(<ClassName>) to the
+// FOR_EACH_TYPED_ARENA macro below.
+#define FOR_EACH_TYPED_ARENA(H) \
H(Node) \
H(CSSValue)

Powered by Google App Engine
This is Rietveld 408576698